# -*- coding: utf-8 -*-

import datetime

from django.db.models import Q
from kinder.core.direct.models import Direct
from kinder.core.direct.models import DRS


def get_direct_ids(mo_id, filter):
    return Direct.objects.filter(
        declaration__mo__id=mo_id).filter(filter()).order_by(
        'declaration__children', '-date').distinct(
        'declaration__children').values_list('id', flat=True)


def get_32_filter():
    """Фильтр для показателя 32
    Показывать последнее выданное направление, если у ребенка их несколько
    в период
    - направления в статусе "Направлен в ДОУ", "Заключение договора", "зачислен"
    - дата создания направления: [01.01.2019 - текущая дата],
    т.е текущий календарный год
    """
    today_ = datetime.date.today()
    return Q(status__code__in=[DRS.ACCEPT, DRS.DOGOVOR, DRS.REGISTER],
             date__range=(datetime.date(today_.year, 1, 1), today_))


def get_321_filter():
    """То же и в  32, изменен список статусов направлений
    - направления в статусе "Направлен в ДОУ", "Заключение договора",
    "Желает изменить ДОУ", "Не явился", "Отказано"
    """
    today_ = datetime.date.today()
    return Q(status__code__in=[DRS.DOGOVOR, DRS.REGISTER, DRS.NEED_CHANGE,
                               DRS.REJECT, DRS.REFUSED],
             date__range=(datetime.date(today_.year, 1, 1), today_))


def get_322_filter():
    """32.2
    - Количество детей, с Направлениями в статусе "Не явился",
    "Желает изменить ДОО"
    - Указывать в доо по первому приоритету
    - дата создания направления: [01.01.2018 - текущая дата],
    т.е текущий календарный год


    """
    today_ = datetime.date.today()
    return Q(status__code__in=[DRS.REJECT, DRS.NEED_CHANGE],
             date__range=(datetime.date(today_.year, 1, 1), today_))
